@@ -5,14 +5,14 @@ from django.dispatch import receiver
 
 from django.db.models.signals import post_save, pre_save
 from django.dispatch import receiver
-from mad_webhooks.models import Log
+from mad_webhooks.models import get_log_model, get_event_model
 
 from mad_webhooks.tasks import makeEventFromLogTask
 
 
 
-@receiver(post_save, sender=Log)
-def makeEventFromLogSignal(sender, instance, created, **kwargs):
+@receiver(post_save, sender=get_log_model())
+def LogPostSaveSignal(sender, instance, created, **kwargs):
     """
     Receive signal on webhook event and add it to queue
     """
